@@ -18,3 +18,7 @@ def on_page_context(app, pagename, templatename, context, doctree):
 
 def setup(app):
     app.connect('html-page-context', on_page_context)
+
+    return {
+        'parallel_read_safe': True,
+    }
