@@ -15,10 +15,11 @@ copyright = u'2015, readthedocs'
 author = u'readthedocs'
 version = '0.1'
 release = '0.1'
-language = None
+language = 'en'
 exclude_patterns = ['_build']
 pygments_style = 'sphinx'
 todo_include_todos = False
 html_theme = 'alabaster'
 html_static_path = ['_static']
 htmlhelp_basename = 'pyexampledoc'
+html_baseurl = 'https://example.com/'
