@@ -15,7 +15,7 @@ copyright = u'2015, readthedocs'
 author = u'readthedocs'
 version = '0.1'
 release = '0.1'
-language = None
+language = 'en'
 exclude_patterns = ['_build']
 pygments_style = 'sphinx'
 todo_include_todos = False
@@ -29,4 +29,5 @@ html_context = {
     'user_analytics_code': '',
     'global_analytics_code': "malic''ious",
     'commit': 'deadd00d',
+    'canonical_url': 'https://example.com/"',
 }
